@@ -1,4 +1,4 @@
-from pip_audit.service.interface import Dependency
+from pip_audit._service.interface import Dependency
 
 
 def test_dependency_source(dep_source):
