@@ -1,23 +1,12 @@
-import tempfile
-from typing import List, Optional
+from typing import List
 
 import pretend
 import pytest
 import requests
 from packaging.version import Version
 
-import pip_audit.service as service
-
-cache_dir: Optional[tempfile.TemporaryDirectory] = None
-
-
-def setup_function(function):
-    global cache_dir
-    cache_dir = tempfile.TemporaryDirectory()
-
-
-def teardown_function(function):
-    cache_dir.cleanup()
+import pip_audit._service as service
+from pip_audit._service.pypi import _get_cache_dir
 
 
 def get_mock_session(func):
@@ -25,13 +14,13 @@ def get_mock_session(func):
         def __init__(self, create_response):
             self.create_response = create_response
 
-        def get(self, url):
+        def get(self, url, **kwargs):
             return self.create_response()
 
     return MockSession(func)
 
 
-def test_pypi():
+def test_pypi(cache_dir):
     pypi = service.PyPIService(cache_dir)
     dep = service.Dependency("jinja2", Version("2.4.1"))
     results: List[service.VulnerabilityResult] = dict(pypi.query_all([dep]))
@@ -41,7 +30,7 @@ def test_pypi():
     assert len(vulns) > 0
 
 
-def test_pypi_multiple_pkg():
+def test_pypi_multiple_pkg(cache_dir):
     pypi = service.PyPIService(cache_dir)
     deps: List[service.Dependency] = [
         service.Dependency("jinja2", Version("2.4.1")),
@@ -54,7 +43,7 @@ def test_pypi_multiple_pkg():
     assert len(results[deps[1]]) > 0
 
 
-def test_pypi_http_notfound(monkeypatch):
+def test_pypi_http_notfound(monkeypatch, cache_dir):
     # If we get a "not found" response, that means that we're querying a package or version that
     # isn't known to PyPI. If that's the case, we should just log a warning and continue on with
     # the audit.
@@ -83,7 +72,7 @@ def test_pypi_http_notfound(monkeypatch):
     assert len(logger.warning.calls) == 1
 
 
-def test_pypi_http_error(monkeypatch):
+def test_pypi_http_error(monkeypatch, cache_dir):
     # Any error response other than "not found" should raise an error.
     def get_error_response():
         class MockResponse:
@@ -105,7 +94,7 @@ def test_pypi_http_error(monkeypatch):
         dict(pypi.query_all([dep]))
 
 
-def test_pypi_mocked_response(monkeypatch):
+def test_pypi_mocked_response(monkeypatch, cache_dir):
     def get_mock_response():
         class MockResponse:
             def raise_for_status(self):
@@ -141,7 +130,7 @@ def test_pypi_mocked_response(monkeypatch):
     )
 
 
-def test_pypi_no_vuln_key(monkeypatch):
+def test_pypi_no_vuln_key(monkeypatch, cache_dir):
     def get_mock_response():
         class MockResponse:
             def raise_for_status(self):
@@ -164,7 +153,7 @@ def test_pypi_no_vuln_key(monkeypatch):
     assert not results[dep]
 
 
-def test_pypi_invalid_version(monkeypatch):
+def test_pypi_invalid_version(monkeypatch, cache_dir):
     def get_mock_response():
         class MockResponse:
             def raise_for_status(self):
@@ -193,7 +182,7 @@ def test_pypi_invalid_version(monkeypatch):
         dict(pypi.query_all([dep]))
 
 
-def test_pypi_warns_about_old_pip(monkeypatch):
+def test_pypi_warns_about_old_pip(monkeypatch, cache_dir):
     monkeypatch.setattr(service.pypi, "_PIP_VERSION", Version("1.0.0"))
     logger = pretend.stub(warning=pretend.call_recorder(lambda s: None))
     monkeypatch.setattr(service.pypi, "logger", logger)
@@ -207,3 +196,44 @@ def test_pypi_warns_about_old_pip(monkeypatch):
     # have an old `pip`, then we should expect a warning to be logged
     service.PyPIService()
     assert len(logger.warning.calls) == 1
+
+
+def test_pypi_cache_dir(monkeypatch):
+    # When we supply a cache directory, always use that
+    cache_dir: str = _get_cache_dir("/tmp/foo/cache_dir")
+    assert cache_dir == "/tmp/foo/cache_dir"
+
+    def run_mock(args, **kwargs):
+        class MockProcess:
+            def __init__(self, stdout_str: str):
+                self.stdout: bytes = stdout_str.encode("utf-8")
+
+        return MockProcess("/Users/foo/Library/Caches/pip")
+
+    # Without a cache dir, query `pip` for its HTTP cache and then append `http` at the end
+    monkeypatch.setattr(service.pypi, "run", run_mock)
+
+    cache_dir = _get_cache_dir(None)
+    assert cache_dir == "/Users/foo/Library/Caches/pip/http"
+
+
+def test_pypi_cache_dir_old_pip(monkeypatch):
+    # Check the case where we have an old `pip`
+    monkeypatch.setattr(service.pypi, "_PIP_VERSION", Version("1.0.0"))
+
+    # When we supply a cache directory, always use that
+    cache_dir: str = _get_cache_dir("/tmp/foo/cache_dir")
+    assert cache_dir == "/tmp/foo/cache_dir"
+
+    # Mock out home since this is going to be different across systems
+    class MockPath:
+        @staticmethod
+        def home():
+            return "/Users/foo"
+
+    # In this case, we can't query `pip` to figure out where its HTTP cache is
+    # Instead, we use `~/.pip-audit-cache`
+    monkeypatch.setattr(service.pypi, "Path", MockPath)
+
+    cache_dir = _get_cache_dir(None)
+    assert cache_dir == "/Users/foo/.pip-audit-cache"
